@@ -1,5 +1,7 @@
 from . import ml_model
 from . import dump_ticket_classifier
+from . import digit_recognizer
+from . import digit_recognizer_utils
 from yaml import load, FullLoader
 import pkgutil
 import os
